import _extends from "@babel/runtime/helpers/esm/extends";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

/**
 *  异步搜索框, 支持搜索结果多选
 *  2021/09/15
 */
import React, { forwardRef, useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import { fetch } from '../../../common/api';
import { log } from '../../../common/tool';
import { Divider, Row, Col, Input, List, message } from 'antd';
var Search = Input.Search;
var ListItem = List.Item;
var AjaxInputSearch = /*#__PURE__*/forwardRef(function (props, ref) {
  var value = props.value,
      apiName = props.apiName,
      apikeyWord = props.apikeyWord,
      apiParams = props.apiParams,
      apiMethod = props.apiMethod,
      isSearchBtn = props.isSearchBtn,
      isdropDown = props.isdropDown,
      selectItemName = props.selectItemName,
      onChange = props.onChange,
      onSelect = props.onSelect,
      getSearchList = props.getSearchList,
      onVerifyVal = props.onVerifyVal;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      loading = _useState2[0],
      setloading = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      open = _useState4[0],
      setOpen = _useState4[1];

  var _useState5 = useState(false),
      _useState6 = _slicedToArray(_useState5, 2),
      isHover = _useState6[0],
      setHover = _useState6[1]; // 鼠标移入


  var _useState7 = useState([]),
      _useState8 = _slicedToArray(_useState7, 2),
      dropDownList = _useState8[0],
      setDropDownList = _useState8[1];

  var timeout = null; // 请求下拉菜单

  var getDropDownList = function getDropDownList(keyWord) {
    setloading(true);
    var queryParms = {};
    queryParms[apikeyWord] = keyWord;
    fetch(apiName, _objectSpread(_objectSpread({}, apiParams), queryParms), apiMethod).then(function (res) {
      var datas = res && res.data ? res.data : [];
      setDropDownList(datas);
      setTimeout(function () {
        setloading(false);
      }, 500);
      getSearchList && getSearchList(datas);
    }).catch(function (err) {
      setloading(false);
      log.error(err);
      message.error("\u83B7\u53D6\u5931\u8D25:".concat(err.message));
    });
  }; // 值变化


  var searchOnChange = function searchOnChange(e) {
    var val = e.target.value;
    val = val.trim();
    if (onVerifyVal && !onVerifyVal(val)) return;
    onChange && onChange(val);
    if (isSearchBtn) return;

    if (!val) {
      setDropDownList([]);
      setOpen(false);
    } else {
      if (timeout) {
        clearTimeout(timeout);
        timeout = null;
      }

      timeout = setTimeout(function () {
        getDropDownList(val);
      }, 300);
      setOpen(true);
    }
  }; // 搜索


  var searchOnSearch = function searchOnSearch(selectVal) {
    if (selectVal) {
      onChange && onChange(selectVal);
      getDropDownList(selectVal);
      setOpen(true);
    } else {
      setDropDownList([]);
      setOpen(false);
    }
  }; // 下拉菜单选中


  var searchOnSelect = function searchOnSelect(selectVal, index) {
    var newList = JSON.parse(JSON.stringify(dropDownList));
    newList.forEach(function (item) {
      item.active = item[selectItemName] === selectVal[selectItemName];
    });
    setDropDownList(newList);
    onSelect && onSelect(selectVal, index);
    onChange && onChange(selectVal[selectItemName]);
    setOpen(false);
  }; // 获取焦点


  var searchOnFocus = function searchOnFocus() {
    if (isdropDown && value) {
      if (!dropDownList || dropDownList.length < 1) {
        if (timeout) {
          clearTimeout(timeout);
          timeout = null;
        }

        timeout = setTimeout(function () {
          getDropDownList(value);
        }, 300);
      }

      setOpen(true);
    }
  }; // 失去焦点


  var searchOnBlur = function searchOnBlur() {
    if (!isHover) {
      setOpen(false);
    }
  };

  var defaultProps = {};

  if (isSearchBtn) {
    defaultProps = {
      enterButton: '搜索',
      onSearch: searchOnSearch
    };
  }

  return /*#__PURE__*/React.createElement("div", {
    ref: ref,
    className: "ajax-input-search"
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Search, _extends({}, defaultProps, {
    allowClear: true,
    placeholder: "\u8BF7\u8F93\u5165",
    onChange: searchOnChange,
    onFocus: searchOnFocus,
    onBlur: searchOnBlur,
    value: value
  }))), /*#__PURE__*/React.createElement("div", {
    className: "search-drop-down",
    style: {
      display: isdropDown && open ? 'block' : 'none'
    },
    onMouseOver: function onMouseOver() {
      return setHover(true);
    },
    onMouseOut: function onMouseOut() {
      return setHover(false);
    }
  }, /*#__PURE__*/React.createElement(List, {
    loading: loading,
    locale: {
      emptyText: '暂无数据'
    },
    split: false,
    size: "small",
    className: "drop-down-list",
    dataSource: dropDownList,
    renderItem: function renderItem(item) {
      return /*#__PURE__*/React.createElement(ListItem, {
        className: item.active ? 'drop-down-item-active drop-down-item' : 'drop-down-item',
        onClick: function onClick() {
          return searchOnSelect(item);
        }
      }, selectItemName ? item[selectItemName] : item);
    }
  })));
}); // function AjaxInputSearch (props) {
// }

AjaxInputSearch.defaultProps = {
  apiParams: {},
  apiMethod: 'GET',
  isSearchBtn: false,
  isdropDown: true
};
AjaxInputSearch.propTypes = {
  apiName: PropTypes.string.isRequired,
  // API请求名,由于直接诶读取data.data的数组数据,所以该API不能使用分页
  apiParams: PropTypes.object,
  // 附加产参数
  apiMethod: PropTypes.string,
  // api请求method
  apikeyWord: PropTypes.string.isRequired,
  // 查询参数key
  value: PropTypes.string,
  // api请求method
  selectItemName: PropTypes.string.isRequired,
  // 下拉菜单展示的键值名
  isSearchBtn: PropTypes.bool,
  // 是否显示搜索按钮，显示后输入值不查询，需点击查询
  isdropDown: PropTypes.bool,
  // 是否显示下拉菜单
  onVerifyVal: PropTypes.func,
  // 验证值，返bool , true，查询， false 停止
  onSelect: PropTypes.func,
  // 下拉框选中值
  getSearchList: PropTypes.func,
  // 查询出来的值
  onChange: PropTypes.func // 监听值变化

};
export default AjaxInputSearch;